aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/change_status.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v1/resources/change_status.proto')
-rw-r--r--google/ads/googleads/v1/resources/change_status.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v1/resources/change_status.proto b/google/ads/googleads/v1/resources/change_status.proto
index 2933e7867..0c9ac1305 100644
--- a/google/ads/googleads/v1/resources/change_status.proto
+++ b/google/ads/googleads/v1/resources/change_status.proto
@@ -41,12 +41,12 @@ message ChangeStatus {
pattern: "customers/{customer}/changeStatus/{change_status}"
};
// Immutable. The resource name of the change status.
// Change status resource names have the form:
//
// `customers/{customer_id}/changeStatus/{change_status_id}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/ChangeStatus"
}
@@ -41,12 +41,12 @@ message ChangeStatus {
pattern: "customers/{customer}/changeStatus/{change_status}"
};
- // Immutable. The resource name of the change status.
+ // Output only. The resource name of the change status.
// Change status resource names have the form:
//